@@ -2,7 +2,7 @@
 
     X Windows PCMCIA device control program
 
-    cardinfo.c 1.37 2001/11/14 01:24:36
+    cardinfo.c 1.39 2002/10/09 06:15:11
 
     The contents of this file are subject to the Mozilla Public
     License Version 1.1 (the "License"); you may not use this file
@@ -433,7 +433,6 @@ static void do_update(FL_OBJECT *obj, long data)
 int main(int argc, char *argv[])
 {
     int i, ret, y, major;
-    servinfo_t serv;
     char name[12];
     FL_FORM *form;
     FL_OBJECT *obj;
@@ -467,14 +466,6 @@ int main(int argc, char *argv[])
 	exit(EXIT_FAILURE);
     }
 
-    if (ioctl(st[0].fd, DS_GET_CARD_SERVICES_INFO, &serv) == 0) {
-	if (serv.Revision != CS_RELEASE_CODE)
-	    fprintf(stderr, "Card Services release does not match!\n");
-    } else {
-	fprintf(stderr, "could not get CS revision info!\n");
-	exit(EXIT_FAILURE);
-    }
-    
     /* Switch back to real user privileges, to be safe */
 #ifndef UNSAFE_TOOLS
     setuid(getuid());
@@ -486,7 +477,7 @@ int main(int argc, char *argv[])
     if (setsid() < 0)
 	perror("detaching from tty");
 
-#if (FL_REVISION >= 80)
+#if (FL_VERSION > 0) || (FL_REVISION >= 80)
     fl_flip_yorigin();
     fl_initialize(&argc, argv, "cardinfo", 0, 0);
 #else
@@ -523,7 +514,7 @@ int main(int argc, char *argv[])
     }
 
     event_log = fl_add_browser(FL_NORMAL_BROWSER, 10, 5, 270, 60, "");
-#if (FL_REVISION < 88)
+#if (FL_VERSION == 0) && (FL_REVISION < 88)
     fl_set_browser_leftslider(event_log, 1);
 #endif
     fl_set_browser_fontsize(event_log, FL_SMALL_SIZE);
