@@ -2,7 +2,7 @@
 
     PCMCIA card configuration register dump
 
-    dump_cisreg.c 1.25 2001/08/24 12:16:44
+    dump_cisreg.c 1.31 2001/11/30 23:10:17
 
     The contents of this file are subject to the Mozilla Public
     License Version 1.1 (the "License"); you may not use this file
@@ -31,10 +31,6 @@
     
 ======================================================================*/
 
-#ifndef __linux__
-#include <pcmcia/u_compat.h>
-#endif
-
 #include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -54,8 +50,6 @@
 
 /*====================================================================*/
 
-#ifdef __linux__
-
 static int major = 0;
 
 static int lookup_dev(char *name)
@@ -79,13 +73,10 @@ static int lookup_dev(char *name)
 	return -1;
 }
 
-#endif /* __linux__ */
-
 /*====================================================================*/
 
 static int open_sock(int sock)
 {
-#ifdef __linux__
     static char *paths[] = {
 	"/var/lib/pcmcia", "/var/run", "/dev", "/tmp", NULL
     };
@@ -95,20 +86,15 @@ static int open_sock(int sock)
 
     for (p = paths; *p; p++) {
 	sprintf(fn, "%s/dc%d", *p, getpid());
-	if (mknod(fn, (S_IFCHR|S_IREAD|S_IWRITE), dev) == 0)
-	    break;
+	if (mknod(fn, (S_IFCHR|S_IREAD|S_IWRITE), dev) == 0) {
+	    fd = open(fn, O_RDONLY);
+	    unlink(fn);
+	    if (fd >= 0)
+		return fd;
+	    if (errno == ENODEV) break;
+	}
     }
-    if (!*p)
-	return -1;
-    fd = open(fn, O_RDONLY);
-    unlink(fn);
-    return fd;
-#endif
-#ifdef __BEOS__
-    char fn[B_OS_NAME_LENGTH];
-    sprintf(fn, "/dev/pcmcia/sock%d", sock);
-    return open(fn, O_RDONLY);
-#endif
+    return -1;
 } /* open_sock */
 
 /*====================================================================*/
@@ -241,13 +227,11 @@ int main(int argc, char *argv[])
     u_int mask;
     ds_ioctl_arg_t arg;
 
-#ifdef __linux__
     major = lookup_dev("pcmcia");
     if (major < 0) {
 	fprintf(stderr, "no pcmcia driver in /proc/devices\n");
 	exit(EXIT_FAILURE);
     }
-#endif
     
     for (i = 0; i < MAX_SOCKS; i++) {
 	fd = open_sock(i);
